# libpythonpro

[![Build Status](https://travis-ci.com/lipegomes/libpythonpro.svg?branch=main)](https://travis-ci.com/lipegomes/libpythonpro)
[![Updates](https://pyup.io/repos/github/lipegomes/libpythonpro/shield.svg)](https://pyup.io/repos/github/lipegomes/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/lipegomes/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/lipegomes/libpythonpro/)


Módulo para exemplificar construção de projetos Python no curso PyTools durante o Bootcamp DevPro.

Neste curso é ensinado como contribuir com projetos de código aberto.

## Requerimentos:
- Ter a versão 3 do python instalada no notebook ou pc.
- Criar o ambiente virtual na pasta do projeto e instalar os requirements:
```console
pip install virtualenv
virtualenv .venv
source .venv/bin/activate
pip install -r requirements-dev.txt
```
## Verificar qualidade de código:
```console
flake8
```
## Tópicos a serem abordados:
1. [Git](https://git-scm.com/)
2. [Virtualenv](https://pypi.org/project/virtualenv/)
3. [Pip](https://pypi.org/project/pip/)
4. [Travis CLI](https://www.travis-ci.com/)
5. [PyUp](https://pyup.io/)

## Licença

Este projeto é licenciado sobre a licença GNU Affero General Public License v3.0 - veja [LICENSE](https://github.com/lipegomes/libpythonpro/blob/main/LICENSE) para mais informações.

## Acknowledgments

- Renzo Nuccitelli [LinkedIn](https://www.linkedin.com/in/renzonuccitelli/)

- Este módulo foi construído durante o Bootcamp DevPro do [PythonPro](https://www.python.pro.br/).